==> migrate_wizard-2.0.7-alpha1.tar.gz: migrate_wizard/src/Plugin/FieldTypeMW/FieldTypeMWDefaultMedia.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'default_node' field type.
 *
 * @FieldType(
 *   id = "default_media",
 * )
 */
class FieldTypeMWDefaultMedia extends FieldTypeMWBase {

  public static function getD7MigrationConfig(&$wildcard_yml_config, $array_config, $origin_node, $migration_group_name, $default_langcode = NULL, $langcode = NULL, $translation = FALSE) {
    $mw_database = parent::getMWDatabase($array_config["mw_database"]);
    $suffix = '';
    if($translation){
      $suffix = '_'.$langcode;
    }
    $wildcard_yml_config['id'] = $origin_node.'_'.$array_config["mw_database"].$suffix;
    $wildcard_yml_config['label'] = $origin_node.$suffix;
    $wildcard_yml_config['langcode'] = $langcode;
    $wildcard_yml_config['migration_group'] = $migration_group_name;
    $wildcard_yml_config['migration_tags'][0] = $migration_group_name;
    $wildcard_yml_config['source']['key'] = $mw_database->get('key');
    $wildcard_yml_config['source']['constants']['source_base_path'] = $mw_database->url_files_prod;
    $wildcard_yml_config['process']['temp1'][0]['value'][] = str_replace('_', '/', $origin_node);
    $wildcard_yml_config['process'][$array_config["listmediafields"].'/target_id'][] = [
      'plugin' => 'migration_lookup',
      'migration' => 'files_'.$array_config["mw_database"],
      'source' => 'fid'
    ];
    $wildcard_yml_config["migration_dependencies"]["required"][] = 'files_'.$array_config["mw_database"];
    $wildcard_yml_config["destination"]["default_bundle"] = array_key_first($array_config);
  }
}

==> migrate_wizard-2.0.9-alpha1.tar.gz: migrate_wizard/src/Plugin/FieldTypeMW/FieldTypeMWDefaultMedia.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'default_node' field type.
 *
 * @FieldType(
 *     id="default_media",
 * )
 */
class FieldTypeMWDefaultMedia extends FieldTypeMWBase {

  public static function getD7MigrationConfig(&$wildcard_yml_config, $array_config, $origin_node, $migration_group_name, $default_langcode = NULL, $langcode = NULL, $translation = FALSE) {
    $mw_database = parent::getMWDatabase($array_config['mw_database']);
    $suffix = '';

    if ($translation) {
      $suffix = '_' . $langcode;
    }
    $wildcard_yml_config['id'] = $origin_node . '_' . $array_config['mw_database'] . $suffix;
    $wildcard_yml_config['label'] = $origin_node . $suffix;
    $wildcard_yml_config['langcode'] = $langcode;
    $wildcard_yml_config['migration_group'] = $migration_group_name;
    $wildcard_yml_config['migration_tags'][0] = $migration_group_name;
    $wildcard_yml_config['source']['key'] = $mw_database->get('key');
    $wildcard_yml_config['source']['constants']['source_base_path'] = $mw_database->url_files_prod;
    $wildcard_yml_config['process']['temp1'][0]['value'][] = str_replace('_', '/', $origin_node);
    $wildcard_yml_config['process'][$array_config['listmediafields'] . '/target_id'][] = [
      'plugin' => 'migration_lookup',
      'migration' => 'files_' . $array_config['mw_database'],
      'source' => 'fid',
    ];
    $wildcard_yml_config['migration_dependencies']['required'][] = 'files_' . $array_config['mw_database'];
    $wildcard_yml_config['destination']['default_bundle'] = array_key_first($array_config);
  }

}
